@@ -3,6 +3,7 @@ from pymodbus.transaction import ModbusSocketFramer, ModbusBinaryFramer
 from pymodbus.factory import ClientDecoder
 from pymodbus.exceptions import ConnectionException
 from websocket import create_connection
+from .version import __version__
 
 import requests
 import logging
@@ -21,7 +22,9 @@ class SungrowModbusWebClient(BaseModbusClient):
     """
 
     # See: Appendix 6、Device Information in "Communication Protocol of PV Grid-Connected String Inverters"
+    # https://github.com/bohdan-s/Sungrow-Inverter/blob/main/Modbus%20Information/Communication%20Protocol%20of%20PV%20Grid-Connected%20String%20Inverters_V1.1.37_EN.pdf
     # TD_202103_Sungrow Inverter and Compatible Accessories_V1.0: SG5.0/7.0/10/15/20RT
+    # https://github.com/bohdan-s/Sungrow-Inverter/blob/main/Install%20Guides/TD_202103_Sungrow%20Inverter%20and%20Compatible%20Accessories_V1.0.pdf
     model_codes = {
         "9264": "SG5.0RT",
         "9276": "SG7.0RT",
@@ -79,10 +82,10 @@ class SungrowModbusWebClient(BaseModbusClient):
             logging.info("Token Retrieved: " + self.ws_token)
         else:
             self.ws_token = ""
-            logging.info("Connection Failed", payload_dict['result_msg'] )
+            logging.error("Connection Failed", payload_dict['result_msg'] )
             raise ConnectionException(self.__str__())
         
-        logging.info("Requesting Device Information")
+        logging.debug("Requesting Device Information")
         self.ws_socket.send(json.dumps({ "lang": "en_us", "token": self.ws_token, "service": "runtime" }))
         result =  self.ws_socket.recv()
         payload_dict = json.loads(result)
@@ -93,9 +96,9 @@ class SungrowModbusWebClient(BaseModbusClient):
             self.dev_type = payload_dict['result_data']['list'][0]['dev_type']      
             # Device model, see Appendix 6            
             self.dev_code = next(s for s in self.model_codes if self.model_codes[s] == payload_dict['result_data']['list'][0]['dev_model'])
-            logging.info("Retrieved: dev_type = " + str(self.dev_type) + ", dev_code = " + str(self.dev_code))
+            logging.debug("Retrieved: dev_type = " + str(self.dev_type) + ", dev_code = " + str(self.dev_code))
         else:
-            logging.info("Connection Failed", payload_dict['result_msg'] )
+            logging.warning("Connection Failed", payload_dict['result_msg'] )
             raise ConnectionException(self.__str__())
         
         return self.ws_socket is not None
@@ -124,18 +127,18 @@ class SungrowModbusWebClient(BaseModbusClient):
         count = 256*request[10]+request[11]
         dev_id = str(request[6])
         
-        logging.info("param_type: " + str(param_type) + ", start_address: " + str(address) + ", count: " + str(count) + ", dev_id: " +str(dev_id))       
+        logging.debug("param_type: " + str(param_type) + ", start_address: " + str(address) + ", count: " + str(count) + ", dev_id: " +str(dev_id))       
         
         logging.debug(f'Calling: http://{str(self.dev_host)}/device/getParam?dev_id={dev_id}&dev_type={str(self.dev_type)}&dev_code={str(self.dev_code)}&type=3&param_addr={address}&param_num={count}&param_type={str(param_type)}&token={self.ws_token}&lang=en_us&time123456={str(int(time.time()))}')
         r =requests.get(f'http://{str(self.dev_host)}/device/getParam?dev_id={dev_id}&dev_type={str(self.dev_type)}&dev_code={str(self.dev_code)}&type=3&param_addr={address}&param_num={count}&param_type={str(param_type)}&token={self.ws_token}&lang=en_us&time123456={str(int(time.time()))}')
         if str(r.status_code) == '200':
-            logging.info("Connection Sucsessful: Status code - " + str(r.status_code))
+            logging.debug("Connection Sucsessful: Status code - " + str(r.status_code))
             self.payload_dict = json.loads(str(r.text))
             logging.debug("Payload Dict: " + str(self.payload_dict))
             modbus_data = self.payload_dict['result_data']['param_value'].split(' ')
             modbus_data.pop() # remove null on the end
             data_len = int(len(modbus_data)) # length of data
-            logging.info("Data length: " + str(data_len))
+            logging.debug("Data length: " + str(data_len))
             # Build the Header, The header is consumed by pyModbus and not actually sent to the device
             # [aaaa][bbbb][cccc][dd][ee][ff] a = Transaction ID, b = Protocol ID, c = Message Length (Data + Header of 3), d =  Device ID, e = Function Code, f = Data Length
             self.payload_modbus = ['00', format(request[1], '02x'), '00', '00', '00', format((data_len+3), '02x'), format(request[6], '02x'), format(request[7], '02x'), format(data_len, '02x')]
@@ -147,7 +150,7 @@ class SungrowModbusWebClient(BaseModbusClient):
             return self.payload_modbus
 
         else:
-            logging.info("Connection Failed: Status code - " + str(r.status_code))
+            logging.warning("Connection Failed: Status code - " + str(r.status_code))
             self.ws_token = ""
             return None
 
@@ -183,7 +186,7 @@ class SungrowModbusWebClient(BaseModbusClient):
         # remove the data from the existing payload (pyModbus retrieves 8 byte header first, then data)
         del self.payload_modbus[0:counter]
 
-        logging.info("Requested Size: " + str(size) + ", Returned Size: " + str(counter))
+        logging.debug("Requested Size: " + str(size) + ", Returned Size: " + str(counter))
         logging.debug("Returned Data: " + str(data))
 
         if  int(counter) < int(size):
@@ -198,7 +201,7 @@ class SungrowModbusWebClient(BaseModbusClient):
         """ Builds a string representation of the connection
         :returns: The string representation
         """
-        return "SungrowModbusWebClient(%s:%s)" % (self.dev_host, self.ws_port)
+        return "SungrowModbusWebClient_%s(%s:%s)" % (__version__, self.dev_host, self.ws_port)
 
     def __repr__(self):
         return (
